<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="2.0" xmlns:marc="http://www.loc.gov/MARC21/slim"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" exclude-result-prefixes="marc">
	<xsl:import href="MARC21slimUtils.xsl"/>
	<xsl:output method="xml" encoding="UTF-8" indent="yes"/>
	<xsl:param name="sourcefile"/>
	<xsl:strip-space elements="*"/>
	<xsl:template match="marc:datafield[@tag='245']">
		<marc:datafield>
			<!-- copy attributes -->
			<xsl:copy-of select="@*"/>
			<!-- copy marc:subfield a -->
			<marc:subfield code="a">
				<xsl:variable name="a" select="marc:subfield[@code='a']"/>
				<xsl:choose>
					<xsl:when test="ends-with($a,'.')">
						<xsl:analyze-string select="$a" regex="\.$">
							<xsl:matching-substring>
								<xsl:variable name="punc">
									<xsl:value-of select="."/>
								</xsl:variable>
								<xsl:value-of select="translate($a,$punc,'')"/>
							</xsl:matching-substring>
						</xsl:analyze-string>
					</xsl:when>
					<xsl:when test="ends-with($a,':')">
						<xsl:analyze-string select="$a" regex=":$">
							<xsl:matching-substring>
								<xsl:variable name="punc">
									<xsl:value-of select="."/>
								</xsl:variable>
								<xsl:value-of select="normalize-space(translate($a,$punc,''))"/>
							</xsl:matching-substring>
						</xsl:analyze-string>
					</xsl:when>
					<xsl:when test="ends-with($a,';')">
						<xsl:analyze-string select="$a" regex=";$">
							<xsl:matching-substring>
								<xsl:variable name="punc">
									<xsl:value-of select="."/>
								</xsl:variable>
								<xsl:value-of select="normalize-space(translate($a,$punc,''))"/>
							</xsl:matching-substring>
						</xsl:analyze-string>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$a"/>
					</xsl:otherwise>
				</xsl:choose>
			</marc:subfield>
			<xsl:copy-of select="marc:subfield[@code='n']"/>
			<xsl:copy-of select="marc:subfield[@code='p']"/>
			<!-- insert marc:subfield h-->
			<xsl:choose>
				<xsl:when test="marc:subfield[@code='b']">
					<marc:subfield code="h">[electronic resource] :</marc:subfield>
				</xsl:when>
				<xsl:otherwise>
					<marc:subfield code="h">[electronic resource]</marc:subfield>
				</xsl:otherwise>
			</xsl:choose>
			<!-- copy everything except marc:subfield a,n,p -->
			<xsl:copy-of
				select="node()[not(self::marc:subfield[@code='a']) and not(self::marc:subfield[@code='n']) and not(self::marc:subfield[@code='p'])]"
			/>
		</marc:datafield>
	</xsl:template>
	<xsl:template name="get_file">
		<xsl:param name="string"/>
		<xsl:choose>
			<xsl:when test="contains($string, '\')">
				<xsl:call-template name="get_file">
					<xsl:with-param name="string" select="substring-after($string, '\')"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="substring-before($string, '.')"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="/">
		<marc:collection xmlns:marc="http://www.loc.gov/MARC21/slim"
			xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
			xsi:schemaLocation="http://www.loc.gov/MARC21/slim http://www.loc.gov/standards/marcxml/schema/MARC21slim.xsd">
			<xsl:for-each select="//marc:record">

				<marc:record>
					<leader>
						<xsl:text>03104nam  2200529Ia 45 0</xsl:text>
					</leader>
					<marc:controlfield tag="001">
						<xsl:variable name="withoutmarc">
							<xsl:call-template name="get_file">
								<xsl:with-param name="string" select="$sourcefile"/>
							</xsl:call-template>
						</xsl:variable>
						<xsl:value-of select="substring-before($withoutmarc,'_')"/>
					</marc:controlfield>
					<marc:controlfield tag="008">
						<xsl:variable name="date">
							<xsl:value-of select="current-dateTime()"/>
						</xsl:variable>
						<xsl:variable name="dateparsed">
							<xsl:value-of select="substring($date,3,8)"/>
						</xsl:variable>
						<xsl:value-of select="translate($dateparsed,'-','')"/>
						<xsl:value-of select="substring(marc:controlfield[@tag='008'],7,17)"/>
						<xsl:text>s</xsl:text>
						<xsl:value-of select="substring(marc:controlfield[@tag='008'],25)"/>
					</marc:controlfield>

					<marc:controlfield tag="006">
						<xsl:text>m        d        </xsl:text>
					</marc:controlfield>
					<marc:controlfield tag="007">
						<xsl:text>cr\mnu</xsl:text>
					</marc:controlfield>
					<marc:datafield tag="040" ind1=" " ind2=" ">
						<marc:subfield code="a">NRC</marc:subfield>
						<marc:subfield code="c">NRC</marc:subfield>
					</marc:datafield>
					<xsl:copy-of select="marc:datafield[@tag='020']"/>
					<xsl:copy-of select="marc:datafield[@tag='022']"/>
					<xsl:copy-of select="marc:datafield[@tag='041']"/>
					<xsl:copy-of select="marc:datafield[@tag='043']"/>
					<xsl:copy-of select="marc:datafield[@tag='050']"/>
					<xsl:copy-of select="marc:datafield[@tag='086']"/>
					<xsl:copy-of select="marc:datafield[@tag='090']"/>
					<xsl:copy-of select="marc:datafield[@tag='100']"/>
					<xsl:copy-of select="marc:datafield[@tag='110']"/>
					<xsl:copy-of select="marc:datafield[@tag='111']"/>
					<xsl:copy-of select="marc:datafield[@tag='130']"/>
					<xsl:copy-of select="marc:datafield[@tag='210']"/>
					<xsl:copy-of select="marc:datafield[@tag='222']"/>
					<xsl:copy-of select="marc:datafield[@tag='240']"/>
					<!--INSERT 245 CODING HERE-->
					<xsl:apply-templates select="marc:datafield[@tag='245']"/>
					<xsl:copy-of select="marc:datafield[@tag='246']"/>
					<xsl:copy-of select="marc:datafield[@tag='250']"/>
					<xsl:copy-of select="marc:datafield[@tag='260']"/>
					<xsl:copy-of select="marc:datafield[@tag='300']"/>
					<xsl:copy-of select="marc:datafield[@tag='310']"/>
					<xsl:copy-of select="marc:datafield[@tag='321']"/>
					<xsl:copy-of select="marc:datafield[@tag='362']"/>
					<xsl:copy-of select="marc:datafield[@tag='440']"/>
					<xsl:copy-of select="marc:datafield[@tag='490']"/>
					<xsl:copy-of select="marc:datafield[@tag='500']"/>
					<xsl:copy-of select="marc:datafield[@tag='501']"/>
					<xsl:copy-of select="marc:datafield[@tag='505']"/>
					<xsl:copy-of select="marc:datafield[@tag='520']"/>
					<marc:datafield tag="533" ind1=" " ind2=" ">
						<marc:subfield code="a">Electronic reproduction.</marc:subfield>
						<marc:subfield code="b">San Francisco, Calif. :</marc:subfield>
						<marc:subfield code="c">Internet Archive,</marc:subfield>
						<marc:subfield code="d">
							<xsl:variable name="date">
								<xsl:value-of select="current-dateTime()"/>
							</xsl:variable>
							<xsl:variable name="dateparsed">
								<xsl:value-of select="substring($date,1,4)"/>
							</xsl:variable>
							<xsl:value-of select="$dateparsed"/>
							<xsl:text>.</xsl:text>
						</marc:subfield>
						<marc:subfield code="n">Available via the World Wide Web.</marc:subfield>
					</marc:datafield>
					<xsl:copy-of select="marc:datafield[@tag='590']"/>
					<xsl:copy-of select="marc:datafield[@tag='600']"/>
					<xsl:copy-of select="marc:datafield[@tag='610']"/>
					<xsl:copy-of select="marc:datafield[@tag='611']"/>
					<xsl:copy-of select="marc:datafield[@tag='650']"/>
					<xsl:copy-of select="marc:datafield[@tag='651']"/>
					<xsl:copy-of select="marc:datafield[@tag='655']"/>
					<xsl:copy-of select="marc:datafield[@tag='700']"/>
					<xsl:copy-of select="marc:datafield[@tag='710']"/>
					<marc:datafield tag="710" ind1="2" ind2=" ">
						<marc:subfield code="a">Open Content Alliance.</marc:subfield>
					</marc:datafield>
					<xsl:copy-of select="marc:datafield[@tag='711']"/>
					<xsl:copy-of select="marc:datafield[@tag='720']"/>
					<xsl:copy-of select="marc:datafield[@tag='730']"/>
					<xsl:copy-of select="marc:datafield[@tag='740']"/>
					<marc:datafield tag="776" ind1="1" ind2=" ">
						<marc:subfield code="c">Original</marc:subfield>
						<xsl:if test="marc:datafield[@tag='020']">
							<marc:subfield code="z">
								<xsl:value-of select="marc:datafield[@tag='020']"/>
							</marc:subfield>
						</xsl:if>
						<xsl:if test="marc:datafield[@tag='022']">
							<marc:subfield code="x">
								<xsl:value-of select="marc:datafield[@tag='022']"/>
							</marc:subfield>
						</xsl:if>
						<xsl:if test="marc:datafield[@tag='010']">
							<marc:subfield code="w">
								<xsl:text>(DLC)</xsl:text>
								<xsl:value-of select="marc:datafield[@tag='010']"/>
							</marc:subfield>
						</xsl:if>
						<xsl:for-each select="marc:datafield[@tag='035']">
							<xsl:if test="contains(marc:subfield[@code='a'],'OCoLC')">
								<marc:subfield code="w">
									<xsl:value-of select="marc:subfield[@code='a']"/>
								</marc:subfield>
							</xsl:if>
						</xsl:for-each>
					</marc:datafield>
					<xsl:copy-of select="marc:datafield[@tag='800']"/>
					<xsl:copy-of select="marc:datafield[@tag='810']"/>
					<xsl:copy-of select="marc:datafield[@tag='830']"/>
					<marc:datafield tag="856" ind1="4" ind2="0">
						<marc:subfield code="u">
							<xsl:text>http://www.archive.org/details/</xsl:text>
							<xsl:variable name="withoutmarc">
								<xsl:call-template name="get_file">
									<xsl:with-param name="string" select="$sourcefile"/>
								</xsl:call-template>
							</xsl:variable>
							<xsl:value-of select="substring-before($withoutmarc,'_')"/>
							<!--	<xsl:value-of select="substring-before($filename,'_')"/>-->
						</marc:subfield>
					</marc:datafield>
					<marc:datafield tag="949" ind1=" " ind2=" ">
						<marc:subfield code="h">ONLINEBOOK</marc:subfield>
					</marc:datafield>
				</marc:record>
			</xsl:for-each>
		</marc:collection>
	</xsl:template>
</xsl:stylesheet>
